@@ -8,7 +8,7 @@ BEGIN {
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 
@@ -16,14 +16,9 @@ sub new {
     my $class = shift;
     my %args = @_;
     my $self = {
-        1 => $args{1} || {
-            1 => { probability => '0.5', payoff => [1,0] },
-            2 => { probability => '0.5', payoff => [0,1] },
-        },
-        2 => $args{2} || {
-            1 => { probability => '0.5', payoff => [1,0] },
-            2 => { probability => '0.5', payoff => [0,1] },
-        },
+        1 => $args{1} || { 1 => '0.5', 2 => '0.5' },
+        2 => $args{2} || { 1 => '0.5', 2 => '0.5' },
+        payoff => $args{payoff} || [ [1,0], [0,1] ],
     };
     bless $self, $class;
     return $self;
@@ -32,9 +27,20 @@ sub new {
 
 sub expected_value
 {
-    my ( $self, $player ) = @_;
+    my ($self) = @_;
+
     my $expected_value = 0;
-    # TODO
+    # For each strategy of player 1...
+    for my $i ( keys %{ $self->{1} } )
+    {
+        # For each strategy of player 2...
+        for my $j ( keys %{ $self->{2} } )
+        {
+            # Expected value is the sum of the probabilities of each payoff
+            $expected_value += $self->{1}{$i} * $self->{2}{$j} * $self->{payoff}[$i - 1][$j - 1];
+        }
+    }
+
     return $expected_value;
 }
 
@@ -52,7 +58,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -73,10 +79,11 @@ to the tabular format of a matrix game:
                   Player 2
                   --------
          Strategy 0.5  0.5
- Player |   0.5    1    0  < Utility
+ Player |   0.5    1    0  < Payoff
     1   |   0.5    0    1  <
 
-The above is a simple, symmetrical zero-sum game, i.e. "matching pennies."
+The above is the default - a simple, symmetrical zero-sum game, i.e. "matching
+pennies."
 
 =head1 METHODS
 
@@ -84,14 +91,10 @@ The above is a simple, symmetrical zero-sum game, i.e. "matching pennies."
 
   $g = Game::Theory::TwoPersonMatrix->new();
   $g = Game::Theory::TwoPersonMatrix->new(
-        1 => {
-            1 => { probability => '0.5', payoff => [1,0] },
-            2 => { probability => '0.5', payoff => [0,1] },
-        },
-        2 => {
-            1 => { probability => '0.5', payoff => [1,0] },
-            2 => { probability => '0.5', payoff => [0,1] },
-        },
+        1 => { 1 => '0.5', 2 => '0.5' },
+        2 => { 1 => '0.5', 2 => '0.5' },
+        payoff => [ [1,0],
+                    [0,1] ]
   );
 
 Create a new C<Game::Theory::TwoPersonMatrix> object.
